@@ -5,7 +5,7 @@ package Mojolicious::Plugin::YamlConfig;
 
 use base 'Mojolicious::Plugin::JSONConfig';
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.2.3';
 
 sub register {
     my ( $self, $app, $conf ) = @_;
@@ -92,7 +92,7 @@ L<YAML> via the C<class> option to parse the data with a more advanced YAML pars
 
 =head2 AUTHOR
 
-Danijel Tasov <data@cpan.org>
+Danijel Tasov <cpan@rbfh.de>
 
 =head2 SEE ALSO
 
